summaryrefslogtreecommitdiffstatshomepage
path: root/src/emu/ui/ui.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/emu/ui/ui.c')
-rw-r--r--src/emu/ui/ui.c28
1 files changed, 14 insertions, 14 deletions
diff --git a/src/emu/ui/ui.c b/src/emu/ui/ui.c
index 3fef4bd074d..fbcf3dfc693 100644
--- a/src/emu/ui/ui.c
+++ b/src/emu/ui/ui.c
@@ -124,8 +124,8 @@ static INT32 slider_overyscale(running_machine &machine, void *arg, std::string
static INT32 slider_overxoffset(running_machine &machine, void *arg, std::string *str, INT32 newval);
static INT32 slider_overyoffset(running_machine &machine, void *arg, std::string *str, INT32 newval);
static INT32 slider_flicker(running_machine &machine, void *arg, std::string *str, INT32 newval);
-static INT32 slider_beam_min(running_machine &machine, void *arg, std::string *str, INT32 newval);
-static INT32 slider_beam_max(running_machine &machine, void *arg, std::string *str, INT32 newval);
+static INT32 slider_beam_width_min(running_machine &machine, void *arg, std::string *str, INT32 newval);
+static INT32 slider_beam_width_max(running_machine &machine, void *arg, std::string *str, INT32 newval);
static INT32 slider_beam_intensity_weight(running_machine &machine, void *arg, std::string *str, INT32 newval);
static char *slider_get_screen_desc(screen_device &screen);
#ifdef MAME_DEBUG
@@ -1969,9 +1969,9 @@ static slider_state *slider_init(running_machine &machine)
// add vector control
*tailptr = slider_alloc(machine, "Vector Flicker", 0, 0, 1000, 10, slider_flicker, NULL);
tailptr = &(*tailptr)->next;
- *tailptr = slider_alloc(machine, "Beam Width Minimum", 1, 100, 1000, 1, slider_beam_min, NULL);
+ *tailptr = slider_alloc(machine, "Beam Width Minimum", 1, 100, 1000, 1, slider_beam_width_min, NULL);
tailptr = &(*tailptr)->next;
- *tailptr = slider_alloc(machine, "Beam Width Maximum", 1, 100, 1000, 1, slider_beam_max, NULL);
+ *tailptr = slider_alloc(machine, "Beam Width Maximum", 1, 100, 1000, 1, slider_beam_width_max, NULL);
tailptr = &(*tailptr)->next;
*tailptr = slider_alloc(machine, "Beam Intensity Weight", -1000, 0, 1000, 10, slider_beam_intensity_weight, NULL);
tailptr = &(*tailptr)->next;
@@ -2354,34 +2354,34 @@ static INT32 slider_flicker(running_machine &machine, void *arg, std::string *st
//-------------------------------------------------
// slider_beam_min - minimum vector beam width slider
// callback
//-------------------------------------------------
-static INT32 slider_beam_min(running_machine &machine, void *arg, std::string *str, INT32 newval)
+static INT32 slider_beam_width_min(running_machine &machine, void *arg, std::string *str, INT32 newval)
{
vector_device *vector = NULL;
if (newval != SLIDER_NOCHANGE)
- vector->set_beam_min(MIN((float)newval * 0.01f, vector->get_beam_max()));
+ vector->set_beam_width_min(MIN((float)newval * 0.01f, vector->get_beam_width_max()));
if (str != NULL)
- strprintf(*str,"%1.2f", (double) vector->get_beam_min());
- return floor(vector->get_beam_min() * 100.0f + 0.5f);
+ strprintf(*str,"%1.2f", (double) vector->get_beam_width_min());
+ return floor(vector->get_beam_width_min() * 100.0f + 0.5f);
}
//-------------------------------------------------
// slider_beam_max - maximum vector beam width slider
// callback
//-------------------------------------------------
-static INT32 slider_beam_max(running_machine &machine, void *arg, std::string *str, INT32 newval)
+static INT32 slider_beam_width_max(running_machine &machine, void *arg, std::string *str, INT32 newval)
{
vector_device *vector = NULL;
if (newval != SLIDER_NOCHANGE)
- vector->set_beam_max(MAX((float)newval * 0.01f, vector->get_beam_min()));
+ vector->set_beam_width_max(MAX((float)newval * 0.01f, vector->get_beam_width_min()));
if (str != NULL)
- strprintf(*str,"%1.2f", (double) vector->get_beam_max());
- return floor(vector->get_beam_max() * 100.0f + 0.5f);
+ strprintf(*str,"%1.2f", (double) vector->get_beam_width_max());
+ return floor(vector->get_beam_width_max() * 100.0f + 0.5f);
}
@@ -2354,34 +2354,34 @@ static INT32 slider_flicker(running_machine &machine, void *arg, std::string *st
//-------------------------------------------------
-// slider_beam_min - minimum vector beam width slider
+// slider_beam_width_min - minimum vector beam width slider
// callback
//-------------------------------------------------
@@ -2354,34 +2354,34 @@ static INT32 slider_flicker(running_machine &machine, void *arg, std::string *st
}
//-------------------------------------------------
-// slider_beam_max - maximum vector beam width slider
+// slider_beam_width_max - maximum vector beam width slider
// callback
//-------------------------------------------------